@@ -1,6 +1,6 @@
 extern char *us_ups_pricing_name[];
 extern void ups_load_rates(void);
-extern char *us_ups_zone_to_price(char *, int, char *);
+extern char *us_ups_zone_to_price(char *, int, char *, int eas);
 extern void ups_world_load(void);
 extern void ups_parcel_types(void);
 extern void ups_country_load(void);
